@@ -45,7 +45,9 @@ class TemplateToolsTests(unittest.TestCase):
             '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
             '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
             '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml', ],
+            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
+            '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
+            '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml', ],
             None,
             None,
             scaling={
@@ -68,7 +70,9 @@ class TemplateToolsTests(unittest.TestCase):
             '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
             '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
             '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml', ],
+            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
+            '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
+            '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml', ],
             None,
             None,
             scaling={
@@ -91,7 +95,9 @@ class TemplateToolsTests(unittest.TestCase):
             '/etc/tuskar/tripleo-heat-templates/block-storage.yaml',
             '/etc/tuskar/tripleo-heat-templates/swift-source.yaml',
             '/etc/tuskar/tripleo-heat-templates/swift-storage-source.yaml',
-            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml', ],
+            '/etc/tuskar/tripleo-heat-templates/ssl-source.yaml',
+            '/etc/tuskar/tripleo-heat-templates/swift-deploy.yaml',
+            '/etc/tuskar/tripleo-heat-templates/nova-compute-config.yaml', ],
             None,
             None,
             scaling={
